==> Daje-Plugin-Apploader-0.02.tar.gz: Daje-Plugin-Apploader-0.02/README.md <==
[![Actions Status](https://github.com/janeskil1525/Daje-Plugin-Apploader/actions/workflows/test.yml/badge.svg)](https://github.com/janeskil1525/Daje-Plugin-Apploader/actions)
# NAME

Daje::Plugin::Apploader - It's new $module

# SYNOPSIS

    load_ables => {
              namespaces => {
                  plugins => [
                      {
                          name => ''
                     }
                  ],
                  routes => [
                      {
                          name => ''
                     }
                  ]
              },
           plugin => [
                  {
                     name => '',
                     options => [
                         {
                             name => '',
                            option => ''
                        }
                    ]
                }
            ],
            helper => [
                {
                    name => '',
                    class => '',
                    options => ''
                }
            ],
            routes => [
                {
                    route => '',
                    target => '',
                    method => ''
                }
            ]
      }
      use Daje::Plugin::Apploader;

      sub register ($self, $app)

# DESCRIPTION

Daje::Plugin::Apploader is ...

# REQUIRES

[Mojo::Loader](https://metacpan.org/pod/Mojo%3A%3ALoader) 

[v5.40](https://metacpan.org/pod/v5.40) 

[Mojo::Base](https://metacpan.org/pod/Mojo%3A%3ABase) 

# METHODS

## register

    register();

# AUTHOR

janeskil1525 <janeskil1525@gmail.com>

# LICENSE

Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

==> Daje-Plugin-Apploader-0.03.tar.gz: Daje-Plugin-Apploader-0.03/README.md <==
[![Actions Status](https://github.com/janeskil1525/Daje-Plugin-Apploader/actions/workflows/test.yml/badge.svg?branch=master)](https://github.com/janeskil1525/Daje-Plugin-Apploader/actions?workflow=test)
# NAME

Daje::Plugin::Apploader - It's new $module

# SYNOPSIS

    load_ables => {
              namespaces => {
                  plugins => [
                      {
                          name => ''
                     }
                  ],
                  routes => [
                      {
                          name => ''
                     }
                  ]
              },
           plugin => [
                  {
                     name => '',
                     options => [
                         {
                             name => '',
                            option => ''
                        }
                    ]
                }
            ],
            helper => [
                {
                    name => '',
                    class => '',
                    options => ''
                }
            ],
            routes => [
                {
                    route => '',
                    target => '',
                    method => ''
                }
            ]
      }
      use Daje::Plugin::Apploader;

      sub register ($self, $app)

# DESCRIPTION

Daje::Plugin::Apploader is ...

# REQUIRES

[Mojo::Loader](https://metacpan.org/pod/Mojo%3A%3ALoader) 

[v5.40](https://metacpan.org/pod/v5.40) 

[Mojo::Base](https://metacpan.org/pod/Mojo%3A%3ABase) 

# METHODS

## register

    register();

# AUTHOR

janeskil1525 <janeskil1525@gmail.com>

# LICENSE

Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.
